﻿'"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
'  © Agilent Technologies, Inc. 2013

' You have a royalty-free right to use, modify, reproduce and distribute
' the Sample Application Files (and/or any modified version) in any way
' you find useful, provided that you agree that Agilent Technologies has no
' warranty,  obligations or liability for any Sample Application Files.

' Agilent Technologies provides programming examples for illustration only,
' This sample program assumes that you are familiar with the programming
' language being demonstrated and the tools used to create and debug
' procedures. Agilent Technologies support engineers can help explain the
' functionality of Agilent Technologies software components and associated
' commands, but they will not modify these samples to provide added
' functionality or construct procedures to meet your specific needs.
' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

' This example shows you how to set up the power supply in both voltage and current priority modes.
' It also shows you how to do a simple measurement.
' This program uses Agilent VISA-COM for instrument communication.

Option Explicit On
Imports Ivi.Visa.Interop

Module Module1

    Sub main()
        Dim ioMgr As ResourceManager
        Dim IOAddress As String
        Dim APS As FormattedIO488

        Dim strResponse As String
        Dim vSet, iSet, ovSet As Double

        vSet = 6
        iSet = 0.5
        ovSet = 15

        ' Set the instrument address.
        IOAddress = "TCPIP0::148.5.218.210"

        ' Start up the VISA_COM IO
        ioMgr = New ResourceManager
        APS = New FormattedIO488

        ' Connect to the instrument.
        APS.IO = ioMgr.Open(IOAddress, AccessMode.EXCLUSIVE_LOCK, 2000, "")

        ' Reset the instrument.
        APS.IO.WriteString("*RST;*CLS")

        ' Identify the instrument.
        APS.IO.WriteString("*IDN?")
        strResponse = APS.IO.ReadString(256)
        Console.WriteLine("The instruments *IDN returns: " & strResponse)

        ' Set up the unit in Voltage Priority, set up the voltage and current, and set the over voltage limit.  Enable the output.
        APS.IO.WriteString("FUNC VOLT")
        APS.IO.WriteString("VOLT " & vSet.ToString)
        APS.IO.WriteString("CURR:LIM " & iSet.ToString)
        APS.IO.WriteString("VOLT:PROT " & ovSet.ToString)
        APS.IO.WriteString("OUTP 1")

        ' *OPC? will ensure that the output is enabled before you take any measurements.
        APS.IO.WriteString("*OPC?")
        strResponse = APS.IO.ReadString(4)

        Console.WriteLine("Voltage Priority Measurements")

        ' Take a voltage measurement in voltage priority mode.
        APS.IO.WriteString("MEAS:VOLT?")
        strResponse = APS.IO.ReadString(32)
        Console.WriteLine("Measured Voltage = " & Left(strResponse, Len(strResponse - 1)))

        'Take a current measurment in voltage priority mode.
        APS.IO.WriteString("MEAS:CURR?")
        strResponse = APS.IO.ReadString(32)
        Console.WriteLine("Measured Current = " & strResponse)

        APS.IO.WriteString("OUTP 0")
        Threading.Thread.Sleep(1000)

        ' Now we will set the unit up in current priority with a negative current limit to sink current.
        ' Note that without a sinkbox you can only sink 10% of the rated output.

        APS.IO.WriteString("FUNC CURR")
        APS.IO.WriteString("VOLT:LIM " & vSet.ToString)
        APS.IO.WriteString("CURR " & (-1 * iSet).ToString)
        APS.IO.WriteString("OUTP 1")

        ' *OPC? will ensure that the output is enabled before you take any measurements.
        APS.IO.WriteString("*OPC?")
        strResponse = APS.IO.ReadString(4)

        Console.WriteLine("Current Priority Measurements")

        ' Take a voltage measurement.
        APS.IO.WriteString("MEAS:VOLT?")
        strResponse = APS.IO.ReadString(32)
        Console.WriteLine("Measured Voltage = " & Left(strResponse, Len(strResponse - 1)))

        'Take a current measurment.
        APS.IO.WriteString("MEAS:CURR?")
        strResponse = APS.IO.ReadString(32)
        Console.WriteLine("Measured Current = " & strResponse)

        ' Close the communication path with the instrument. 
        APS.IO.Close()

        Console.WriteLine("Press Enter to exit")

        Console.ReadLine()


    End Sub


End Module
